==> qtjambi-websockets-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiWebSockets/QWebSocketServer_shell.h <==
#ifndef QWEBSOCKETSERVER_SHELL_H
#define QWEBSOCKETSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebSockets/qwebsocketserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qssl.h>
#if __has_include(<QtNetwork/qsslconfiguration.h>)
#include <QtNetwork/qsslconfiguration.h>
#endif
#if __has_include(<QtNetwork/qsslerror.h>)
#include <QtNetwork/qsslerror.h>
#endif
#include <qtnetwork-config.h>
#if QT_CONFIG(ssl)
#if __has_include(<QtNetwork/qsslpresharedkeyauthenticator.h>)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif
#endif //QT_CONFIG(ssl)
#include <QtNetwork/qtcpsocket.h>
#include <QtWebSockets/qwebsocket.h>
#include <QtWebSockets/qwebsocketcorsauthenticator.h>
#include <QtWebSockets/qwebsocketprotocol.h>
#include <QtJambi/RegistryAPI>


class QWebSocketServer_shell : public QWebSocketServer, public QtJambiShellInterface
{
public:
    QWebSocketServer_shell(const QString& serverName0, QWebSocketServer::SslMode secureMode1, QObject* parent2 = nullptr);
    ~QWebSocketServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QWebSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebSocketServer_access : public QWebSocketServer
{
    jobject __qt_nextPendingConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QWEBSOCKETSERVER_SHELL_H

==> qtjambi-websockets-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiWebSockets/QWebSocketServer_shell.h <==
#ifndef QWEBSOCKETSERVER_SHELL_H
#define QWEBSOCKETSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebSockets/qwebsocketserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(ssl)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif //QT_CONFIG(ssl)
#include <QtNetwork/qtcpsocket.h>
#include <QtWebSockets/qwebsocket.h>
#include <QtWebSockets/qwebsocketcorsauthenticator.h>
#include <QtWebSockets/qwebsocketprotocol.h>
#include <QtJambi/RegistryAPI>


class QWebSocketServer_shell : public QWebSocketServer, public QtJambiShellInterface
{
public:
    QWebSocketServer_shell(const QString& serverName0, QWebSocketServer::SslMode secureMode1, QObject* parent2 = nullptr);
    ~QWebSocketServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QWebSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebSocketServer_access : public QWebSocketServer
{
    jobject __qt_nextPendingConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QWEBSOCKETSERVER_SHELL_H
